package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.PBEParametersGenerator;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.RIPEMD160Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.generators.PKCS12ParametersGenerator;
import cn.com.infosec.crypto.generators.PKCS5S1ParametersGenerator;
import cn.com.infosec.crypto.generators.PKCS5S2ParametersGenerator;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.spec.PBEParameterSpec;

public interface BrokenPBE {
   int MD5 = 0;
   int SHA1 = 1;
   int RIPEMD160 = 2;
   int PKCS5S1 = 0;
   int PKCS5S2 = 1;
   int PKCS12 = 2;
   int OLD_PKCS12 = 3;

   public static class Util {
      private static void setOddParity(byte[] bytes) {
         for(int var1 = 0; var1 < bytes.length; ++var1) {
            byte var2;
            bytes[var1] = (byte)((var2 = bytes[var1]) & 254 | var2 >> 1 ^ var2 >> 2 ^ var2 >> 3 ^ var2 >> 4 ^ var2 >> 5 ^ var2 >> 6 ^ var2 >> 7 ^ 1);
         }

      }

      private static PBEParametersGenerator makePBEGenerator(int type, int hash) {
         Object var10000;
         Object type1;
         SHA1Digest hash1;
         MD5Digest hash2;
         if (type == 0) {
            if (hash != 0) {
               if (hash != 1) {
                  throw new IllegalStateException("PKCS5 scheme 1 only supports only MD5 and SHA1.");
               }

               var10000 = type1 = new PKCS5S1ParametersGenerator;
               hash1 = new SHA1Digest.<init>();
               var10000.<init>(hash1);
            } else {
               var10000 = type1 = new PKCS5S1ParametersGenerator;
               hash2 = new MD5Digest.<init>();
               var10000.<init>(hash2);
            }
         } else if (type == 1) {
            type1 = new PKCS5S2ParametersGenerator.<init>();
         } else {
            RIPEMD160Digest hash3;
            if (type == 3) {
               if (hash != 0) {
                  if (hash != 1) {
                     if (hash != 2) {
                        throw new IllegalStateException("unknown digest scheme for PBE encryption.");
                     }

                     var10000 = type1 = new OldPKCS12ParametersGenerator;
                     hash3 = new RIPEMD160Digest.<init>();
                     var10000.<init>(hash3);
                  } else {
                     var10000 = type1 = new OldPKCS12ParametersGenerator;
                     hash1 = new SHA1Digest.<init>();
                     var10000.<init>(hash1);
                  }
               } else {
                  var10000 = type1 = new OldPKCS12ParametersGenerator;
                  hash2 = new MD5Digest.<init>();
                  var10000.<init>(hash2);
               }
            } else if (hash != 0) {
               if (hash != 1) {
                  if (hash != 2) {
                     throw new IllegalStateException("unknown digest scheme for PBE encryption.");
                  }

                  var10000 = type1 = new PKCS12ParametersGenerator;
                  hash3 = new RIPEMD160Digest.<init>();
                  var10000.<init>(hash3);
               } else {
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  hash1 = new SHA1Digest.<init>();
                  var10000.<init>(hash1);
               }
            } else {
               var10000 = type1 = new PKCS12ParametersGenerator;
               hash2 = new MD5Digest.<init>();
               var10000.<init>(hash2);
            }
         }

         return (PBEParametersGenerator)type1;
      }

      static CipherParameters makePBEParameters(JCEPBEKey pbeKey, AlgorithmParameterSpec spec, int type, int hash, String targetAlgorithm, int keySize, int ivSize) {
         if (spec != null && spec instanceof PBEParameterSpec) {
            PBEParameterSpec spec1 = (PBEParameterSpec)spec;
            PBEParametersGenerator type1;
            PBEParametersGenerator var10001 = type1 = makePBEGenerator(type, hash);
            byte[] pbeKey1 = pbeKey.getEncoded();
            byte[] spec2 = spec1.getSalt();
            hash = spec1.getIterationCount();
            var10001.init(pbeKey1, spec2, hash);
            CipherParameters spec3;
            if (ivSize != 0) {
               spec3 = type1.generateDerivedParameters(keySize, ivSize);
            } else {
               spec3 = type1.generateDerivedParameters(keySize);
            }

            if (targetAlgorithm.startsWith("DES")) {
               if (spec3 instanceof ParametersWithIV) {
                  setOddParity(((KeyParameter)((ParametersWithIV)spec3).getParameters()).getKey());
               } else {
                  setOddParity(((KeyParameter)spec3).getKey());
               }
            }

            for(type = 0; type != pbeKey1.length; ++type) {
               pbeKey1[type] = 0;
            }

            return spec3;
         } else {
            throw new IllegalArgumentException("Need a PBEParameter spec with a PBE key.");
         }
      }

      static CipherParameters makePBEMacParameters(JCEPBEKey pbeKey, AlgorithmParameterSpec spec, int type, int hash, int keySize) {
         if (spec != null && spec instanceof PBEParameterSpec) {
            PBEParameterSpec spec1 = (PBEParameterSpec)spec;
            PBEParametersGenerator var10000 = makePBEGenerator(type, hash);
            byte[] pbeKey1 = pbeKey.getEncoded();
            byte[] spec2 = spec1.getSalt();
            type = spec1.getIterationCount();
            var10000.init(pbeKey1, spec2, type);
            CipherParameters spec3 = var10000.generateDerivedMacParameters(keySize);

            for(type = 0; type != pbeKey1.length; ++type) {
               pbeKey1[type] = 0;
            }

            return spec3;
         } else {
            throw new IllegalArgumentException("Need a PBEParameter spec with a PBE key.");
         }
      }
   }
}
